==> llmapi-1.0.4.tar.gz: llmapi-1.0.4/setup.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""

    LLMAapi
    
    unified openapi for large language models

    :author:    llmapi <llmapi@163.com>
    :homepage:  https://github.com/whlook/
    :license:   MIT, see LICENSE for more details.
    :copyright: Copyright (c) 2023 llmapi. All rights reserved
"""
import codecs
import llmapi
import setuptools.command.test


# -*- Long Description -*-

def long_description():
    try:
        return codecs.open('README.md', 'r', 'utf-8').read()
    except IOError:
        return 'Long description error: Missing README.rst file'


setuptools.setup(
    name=llmapi.__name__,
    version=llmapi.__version__,
    description=llmapi.__description__,
    long_description=long_description(),
    keywords=llmapi.__keywords__,
    author=llmapi.__author__,
    author_email=llmapi.__contact__,
    url=llmapi.__url__,
    license=llmapi.__license__,
    platforms=['any'],
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Natural Language :: Chinese (Simplified)',
        'Natural Language :: English',
        'Topic :: Utilities',
        'Topic :: Terminals',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
    ],
    packages=setuptools.find_packages(exclude=['tests']),
    include_package_data=True,
    package_data={
        '': ['*.py']
    },
    python_requires = '>=3.8',
    install_requires = ['requests','pillow'],
    entry_points={
        'console_scripts': [
            'llmapi = llmapi:main',
        ],
    },
)

==> llmapi-1.0.8.tar.gz: llmapi-1.0.8/setup.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""

    LLMAapi

    unified openapi for large language models

    :author:    llmapi <llmapi@163.com>
    :homepage:  https://github.com/whlook/
    :license:   MIT, see LICENSE for more details.
    :copyright: Copyright (c) 2023 llmapi. All rights reserved
"""
import codecs
import llmapi
import setuptools.command.test


# -*- Long Description -*-

def long_description():
    try:
        return codecs.open('README.md', 'r', 'utf-8').read()
    except IOError:
        return 'Long description error: Missing README.rst file'


setuptools.setup(
    name=llmapi.__name__,
    version=llmapi.__version__,
    description=llmapi.__description__,
    long_description=long_description(),
    keywords=llmapi.__keywords__,
    author=llmapi.__author__,
    author_email=llmapi.__contact__,
    url=llmapi.__url__,
    license=llmapi.__license__,
    platforms=['any'],
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Natural Language :: Chinese (Simplified)',
        'Natural Language :: English',
        'Topic :: Utilities',
        'Topic :: Terminals',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
    ],
    packages=setuptools.find_packages(exclude=['tests']),
    include_package_data=True,
    package_data={
        '': ['*.py']
    },
    python_requires = '>=3.8',
    install_requires = ['requests'],
    entry_points={
        'console_scripts': [
            'llmapi = llmapi:main',
        ],
    },
)
